@@ -71,7 +71,8 @@ import logging
 #  Copy 'run.py' and 'settings.ini' files wherever you want to have your record repository.
 #  Windows let's you double click 'run.py'. Can run from desktop.
 # Magic number 42 is used to connect to all radios found in 'settings.ini'.
-print('0.7.0 now a real Ghetto Blaster with radio')
+
+print('0.7.1 now a real Ghetto Blaster with radio')  # ###################### version ##################################
 
 # - added radio, http server redirects to local port
 # - fixed copy file with wrong name
@@ -104,9 +105,7 @@ def switch_dst_dir(container):  # if app runs in a container
     GBase.radio_base_dir = ghetto_folder
 
     source_ini = os.path.dirname(os.path.abspath(__file__)) + '//settings.ini'
-    source_script = os.path.dirname(os.path.abspath(__file__)) + '//StartGhetto.sh'
     dst_ini = ghetto_folder + '//settings.ini'
-    dst_script = ghetto_folder + '//StartGhetto.sh'
 
     access_rights = 0o755
     try:
@@ -117,11 +116,8 @@ def switch_dst_dir(container):  # if app runs in a container
     try:
         if not os.path.exists(dst_ini):
             shutil.copyfile(source_ini, dst_ini)
-            shutil.copyfile(source_script, dst_script)
     except FileExistsError:
         pass
-    st = os.stat(dst_script)
-    os.chmod(dst_script, st.st_mode | stat.S_IEXEC)
 
 
 def signal_handler(sig, frame):
